@@ -36,7 +36,7 @@ class RBS::CliTest < Test::Unit::TestCase
           rbs_path << (":" + rblib)
         end
 
-        Open3.capture3({ "RUBYLIB" => rbs_path }, *bundle_exec, "#{__dir__}/../../exe/rbs", "collection", *commands, chdir: Dir.pwd)
+        Open3.capture3({ "RUBYLIB" => rbs_path }, *bundle_exec, "#{__dir__}/../../exe/rbs", "--log-level=debug", "collection", *commands, chdir: Dir.pwd)
       end
 
     if block_given?
@@ -55,7 +55,11 @@ class RBS::CliTest < Test::Unit::TestCase
           if gem == :gemspec
             "gemspec"
           else
-            "gem '#{gem}'"
+            if gem.is_a?(Array)
+              "gem #{gem.map(&:inspect).join(", ")}"
+            else
+              "gem '#{gem}'"
+            end
           end
         end
 
@@ -248,9 +252,9 @@ singleton(::BasicObject)
       assert_includes stdout.string, 'accessibility: public'
       assert_includes stdout.string, 'types:'
       assert_includes stdout.string, '  () -> ::Enumerator[self, untyped]'
-      assert_includes stdout.string, 'rbs/core/kernel.rbs'
+      assert_includes stdout.string, 'core/kernel.rbs'
       assert_includes stdout.string, '| [T] () { (self) -> T } -> T'
-      assert_includes stdout.string, 'rbs/core/kernel.rbs'
+      assert_includes stdout.string, 'core/kernel.rbs'
     end
 
     Dir.mktmpdir do |dir|
@@ -851,8 +855,8 @@ singleton(::BasicObject)
   def test_paths
     with_cli do |cli|
       cli.run(%w(-r pathname -I no-such-dir paths))
-      assert_match %r{/rbs/core \(dir, core\)$}, stdout.string
-      assert_match %r{/rbs/stdlib/pathname/0 \(dir, library, name=pathname\)$}, stdout.string
+      assert_match %r{/core \(dir, core\)$}, stdout.string
+      assert_match %r{/stdlib/pathname/0 \(dir, library, name=pathname\)$}, stdout.string
       assert_match %r{^no-such-dir \(absent\)$}, stdout.string
     end
   end
@@ -862,7 +866,7 @@ singleton(::BasicObject)
 
     with_cli do |cli|
       cli.run(%w(-r rbs-amber paths))
-      assert_match %r{/rbs/core \(dir, core\)$}, stdout.string
+      assert_match %r{/core \(dir, core\)$}, stdout.string
       assert_match %r{/sig \(dir, library, name=rbs-amber\)$}, stdout.string
     end
   end
@@ -1288,6 +1292,260 @@ Processing `lib`...
     end
   end
 
+  def test_collection_install__mutex_m__config__bundled
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+
+          gems:
+          - name: mutex_m
+        YAML
+
+        bundle_install(["mutex_m", ">= 0.3.0"])
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        refute_match(/`mutex_m` as a stdlib in rbs-gem is deprecated./, stderr)
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Rubygems, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__config__no_bundled
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+
+          gems:
+          - name: mutex_m
+        YAML
+
+        bundle_install(["mutex_m", "0.2.0"])
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
+        assert_include stderr, 'Add `mutex_m` (>= 0.3.0) to the dependency of your Ruby program to use the gem-bundled type definition.'
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Stdlib, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__config__stdlib_source
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+
+          gems:
+          - name: mutex_m
+            source:
+              type: stdlib
+        YAML
+
+        bundle_install
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
+        assert_include stderr, 'Add `mutex_m` (>= 0.3.0) to the dependency of your Ruby program to use the gem-bundled type definition.'
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Stdlib, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__bundled
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+        YAML
+
+        bundle_install(["mutex_m", ">= 0.3.0"])
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        refute_match(/`mutex_m` as a stdlib in rbs-gem is deprecated./, stderr)
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Rubygems, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__no_bundled
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+        YAML
+
+        bundle_install(["mutex_m", "0.2.0"])
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        assert_include stderr, '`mutex_m` as a stdlib in rbs-gem is deprecated.'
+        assert_include stderr, 'Add `mutex_m` (>= 0.3.0) to the dependency of your Ruby program to use the gem-bundled type definition.'
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Stdlib, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__dependency_no_bundled
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - type: local
+              path: repo
+
+          path: #{dir.join('gem_rbs_collection')}
+        YAML
+
+        (dir/"repo/true_string/0").mkpath
+        (dir/"repo/true_string/0/manifest.yaml").write(<<~YAML)
+          dependencies:
+          - name: mutex_m
+        YAML
+
+        bundle_install("true_string")  # true_string is a soutaro's gem that doesn't have sig directory
+
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        assert_include stderr, '`mutex_m` is included in the RBS dependencies of `true_string`, but the type definition as a stdlib in rbs-gem is deprecated.'
+        assert_include stderr, 'Add `mutex_m` (>= 0.3.0) to the dependency of your Ruby program to use the gem-bundled type definition.'
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Stdlib, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
+  def test_collection_install__mutex_m__rbs_dependency_and__gem_dependency
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        dir = Pathname(dir)
+
+        (dir/"gem").mkpath
+        (dir/"gem/hola.gemspec").write(<<~RUBY)
+          Gem::Specification.new do |s|
+            s.name        = "hola"
+            s.version     = "0.0.0"
+            s.summary     = "Hola!"
+            s.description = "A simple hello world gem"
+            s.authors     = ["Nick Quaranto"]
+            s.email       = "nick@quaran.to"
+            s.files       = ["lib/hola.rb", "sig/hola.rbs"]
+            s.homepage    =
+              "https://rubygems.org/gems/hola"
+            s.license       = "MIT"
+            s.add_runtime_dependency "mutex_m", ">= 0.3.0"
+          end
+        RUBY
+        (dir/"gem/sig").mkpath
+        (dir/"gem/sig/manifest.yaml").write(<<~YAML)
+          dependencies:
+          - name: mutex_m
+        YAML
+
+        bundle_install(["hola", { path: "gem" }])
+
+        (dir + RBS::Collection::Config::PATH).write(<<~YAML)
+          sources:
+            - name: ruby/gem_rbs_collection
+              remote: https://github.com/ruby/gem_rbs_collection.git
+              revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+              repo_dir: gems
+
+          path: #{dir.join('gem_rbs_collection')}
+        YAML
+
+        _stdout, stderr = run_rbs_collection("install", bundler: true)
+
+        assert_include stderr, '`mutex_m` is included in the RBS dependencies of `hola`, but the type definition as a stdlib in rbs-gem is deprecated.'
+        assert_include stderr, 'Delete `mutex_m` from the RBS dependencies of `hola`.'
+
+        lockfile = RBS::Collection::Config::Lockfile.from_lockfile(
+          lockfile_path: dir + "rbs_collection.lock.yaml",
+          data: YAML.safe_load((dir + "rbs_collection.lock.yaml").read)
+        )
+
+        assert_instance_of RBS::Collection::Sources::Rubygems, lockfile.gems["mutex_m"][:source]
+      end
+    end
+  end
+
   def test_subtract
     Dir.mktmpdir do |dir|
       dir = Pathname(dir)
