@@ -40,7 +40,8 @@ end
 
     env = Environment.new
     loaded = loader.load(env: env)
-
+    _, _, lib = loaded.delete_if { |_, _, lib| lib.name == "stringio" }
+    assert lib
     assert loaded.all? {|_, _, path_type| path_type == :core }
   end
 
@@ -63,21 +64,21 @@ end
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::Person")
-      assert_operator env.class_decls, :key?, TypeName("::PeopleController")
-      assert_operator env.class_decls, :key?, TypeName("::Person::Internal")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Person")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::PeopleController")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Person::Internal")
     end
   end
 
   def test_loading_stdlib
     mktmpdir do |path|
       loader = EnvironmentLoader.new
-      loader.add(library: "set")
+      loader.add(library: "uri")
 
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::Set")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::URI")
     end
   end
 
@@ -90,7 +91,7 @@ end
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::Gem")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Gem")
       assert io.string.include?('`rubygems` has been moved to core library')
     end
   ensure
@@ -114,9 +115,9 @@ end
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::Person")
-      assert_operator env.class_decls, :key?, TypeName("::PeopleController")
-      refute_operator env.class_decls, :key?, TypeName("::Person::Internal")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Person")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::PeopleController")
+      refute_operator env.class_decls, :key?, RBS::TypeName.parse("::Person::Internal")
     end
   end
 
@@ -144,12 +145,12 @@ end
       env = Environment.new
       loaded = loader.load(env: env)
 
-      assert_equal 1, loaded.count {|decl, _, _| decl.name == TypeName("Person") }
+      assert_equal 1, loaded.count {|decl, _, _| decl.respond_to?(:name) && decl.name == RBS::TypeName.parse("Person") }
     end
   end
 
   def test_loading_from_gem
-    omit unless has_gem?("rbs-amber")
+    omit "Test gem `rbs-amber` is unavailable" unless has_gem?("rbs-amber")
 
     mktmpdir do |path|
       repo = RBS::Repository.new()
@@ -160,7 +161,7 @@ end
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::Amber")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Amber")
     end
   end
 
@@ -184,14 +185,14 @@ end
   def test_loading_dependencies
     mktmpdir do |path|
       loader = EnvironmentLoader.new
-      loader.add(library: "yaml")
+      loader.add(library: "psych")
 
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::YAML")
-      assert_operator env.class_decls, :key?, TypeName("::DBM")
-      assert_operator env.class_decls, :key?, TypeName("::PStore")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Psych")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::DBM")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::PStore")
     end
   end
 
@@ -234,12 +235,56 @@ end
       env = Environment.new
       loader.load(env: env)
 
-      assert_operator env.class_decls, :key?, TypeName("::AST")
-      assert_operator env.class_decls, :key?, TypeName("::Rainbow")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::AST")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::Rainbow")
       assert repo.dirs.include? lock.fullpath
     end
   end
 
+  def test_loading_from_rbs_collection__gem_version_mismatch
+    omit "Test gem `rbs-amber` is unavailable" unless has_gem?("rbs-amber")
+
+    mktmpdir do |path|
+      lockfile_path = path.join('rbs_collection.lock.yaml')
+      lockfile_path.write(<<~YAML)
+        sources:
+          - name: ruby/gem_rbs_collection
+            remote: https://github.com/ruby/gem_rbs_collection.git
+            revision: b4d3b346d9657543099a35a1fd20347e75b8c523
+            repo_dir: gems
+        path: '.gem_rbs_collection'
+        gems:
+          - name: rbs-amber
+            version: "1.1"
+            source:
+              type: "rubygems"
+      YAML
+      RBS::Collection::Installer.new(lockfile_path: lockfile_path, stdout: StringIO.new).install_from_lockfile
+      lock = RBS::Collection::Config::Lockfile.from_lockfile(lockfile_path: lockfile_path, data: YAML.load_file(lockfile_path))
+
+      repo = RBS::Repository.new()
+
+      loader = EnvironmentLoader.new(repository: repo)
+
+      io = StringIO.new
+      old_output = RBS.logger_output
+      RBS.logger_output = io
+      begin
+        loader.add_collection(lock)
+        env = Environment.new
+        loader.load(env: env)
+      ensure
+        RBS.logger_output = old_output
+      end
+
+      assert_operator(
+        io.string,
+        :include?,
+        "Loading type definition from gem `rbs-amber-1.0.0` because locked version `1.1` is unavailable. Try `rbs collection update` to fix the (potential) issue."
+      )
+    end
+  end
+
   def test_loading_from_rbs_collection_git_source_without_install
     mktmpdir do |path|
       lockfile_path = path.join('rbs_collection.lock.yaml')
