@@ -65,7 +65,7 @@ EOF
       env << decl
     end
 
-    env.class_alias_decls[TypeName("::RBS::Kernel")].tap do |decl|
+    env.class_alias_decls[RBS::TypeName.parse("::RBS::Kernel")].tap do |decl|
       assert_instance_of Environment::ModuleAliasEntry, decl
     end
   end
@@ -175,6 +175,36 @@ EOF
     end
   end
 
+  def test_type_alias_twice_duplication_error
+    env = Environment.new
+
+    _, _, decls = RBS::Parser.parse_signature(<<EOF)
+type foo = String
+type foo = Integer
+EOF
+
+    assert_raises RBS::DuplicatedDeclarationError do
+      env << decls[0]
+      env << decls[1]
+    end
+  end
+
+  def test_interface_twice_duplication_error
+    env = Environment.new
+
+    _, _, decls = RBS::Parser.parse_signature(<<EOF)
+interface _I
+end
+interface _I
+end
+EOF
+
+    assert_raises RBS::DuplicatedDeclarationError do
+      env << decls[0]
+      env << decls[1]
+    end
+  end
+
   def test_generic_class
     env = Environment.new
 
@@ -432,8 +462,8 @@ end
     env.add_signature(buffer: buf, directives: dirs, decls: decls)
 
     env.resolve_type_names.tap do |env|
-      class_decl = env.class_decls[TypeName("::A::B")]
-      assert_equal TypeName("::A::C"), class_decl.primary.decl.super_class.name
+      class_decl = env.class_decls[RBS::TypeName.parse("::A::B")]
+      assert_equal RBS::TypeName.parse("::A::C"), class_decl.primary.decl.super_class.name
     end
   end
 
@@ -513,10 +543,10 @@ end
     env.add_signature(buffer: buf, directives: dirs, decls: decls)
 
     env.resolve_type_names.tap do |env|
-      class_decl = env.class_decls[TypeName("::Foo")]
-      assert_equal TypeName("::Object"), class_decl.primary.decl.super_class.name
+      class_decl = env.class_decls[RBS::TypeName.parse("::Foo")]
+      assert_equal RBS::TypeName.parse("::Object"), class_decl.primary.decl.super_class.name
 
-      assert_operator env.class_decls, :key?, TypeName("::OB")
+      assert_operator env.class_decls, :key?, RBS::TypeName.parse("::OB")
     end
   end
 end
