@@ -231,6 +231,39 @@ class IOInstanceTest < Test::Unit::TestCase
     end
   end
 
+  def test_each_line
+    IO.open(IO.sysopen(File.expand_path(__FILE__)), path: "foo") do |io|
+      assert_send_type(
+        "() -> Enumerator[String, IO]",
+        io, :each_line
+      )
+    end
+
+    IO.open(IO.sysopen(File.expand_path(__FILE__)), path: "foo") do |io|
+      assert_send_type(
+        "() { (String) -> void } -> void",
+        io, :each_line, &->(_x) { }
+      )
+    end
+
+    IO.open(IO.sysopen(File.expand_path(__FILE__)), path: "foo") do |io|
+      with_string("\n") do |sep|
+        with_int(3) do |limit|
+          with_boolish() do |chomp|
+            assert_send_type(
+              "(string, int, chomp: boolish) -> Enumerator[String, IO]",
+              io, :each_line, sep, limit, chomp: chomp
+            )
+            assert_send_type(
+              "(string, int, chomp: boolish) { (String) -> void } -> void",
+              io, :each_line, sep, limit, chomp: chomp, &->(_x) { }
+            )
+            end
+        end
+      end
+    end
+  end
+
   def test_path
     IO.open(IO.sysopen(File.expand_path(__FILE__)), path: "foo") do |io|
       assert_send_type(
@@ -382,6 +415,38 @@ class IOInstanceTest < Test::Unit::TestCase
                        io, :gets, nil, chomp: true
     end
   end
+
+  def test_readlines
+    IO.open(IO.sysopen(File.expand_path(__FILE__))) do |io|
+      assert_send_type '() -> Array[String]',
+                       io, :readlines
+
+      assert_send_type '(String, Integer) -> Array[String]',
+                       io, :readlines, "\n", 100
+
+      assert_send_type '(chomp: bool) -> Array[String]',
+                       io, :readlines, chomp: true
+
+      assert_send_type '(String, Integer, chomp: bool) -> Array[String]',
+                       io, :readlines, "\n", 100, chomp: true
+    end
+  end
+
+  def test_readline
+    IO.open(IO.sysopen(File.expand_path(__FILE__))) do |io|
+      assert_send_type '() -> String',
+                       io, :readline
+
+      assert_send_type '(String, Integer) -> String',
+                       io, :readline, "\n", 100
+
+      assert_send_type '(chomp: bool) -> String',
+                       io, :readline, chomp: true
+
+      assert_send_type '(String, Integer, chomp: bool) -> String',
+                       io, :readline, "\n", 100, chomp: true
+    end
+  end
 end
 
 class IOWaitTest < Test::Unit::TestCase
@@ -390,24 +455,22 @@ class IOWaitTest < Test::Unit::TestCase
   testing "::IO"
 
   def test_readyp
-    if_ruby31 do
-      # This method returns true|false in Ruby 2.7, nil|IO in 3.0, and true|false in 3.1.
+    # This method returns true|false in Ruby 2.7, nil|IO in 3.0, and true|false in 3.1.
 
-      IO.pipe.tap do |r, w|
-        assert_send_type(
-          "() -> untyped",
-          r, :ready?
-        )
-      end
+    IO.pipe.tap do |r, w|
+      assert_send_type(
+        "() -> untyped",
+        r, :ready?
+      )
+    end
 
-      IO.pipe.tap do |r, w|
-        w.write("hello")
+    IO.pipe.tap do |r, w|
+      w.write("hello")
 
-        assert_send_type(
-          "() -> untyped",
-          r, :ready?
-        )
-      end
+      assert_send_type(
+        "() -> untyped",
+        r, :ready?
+      )
     end
   end
 
@@ -459,7 +522,7 @@ class IOWaitTest < Test::Unit::TestCase
   end
 
   def test_wait
-    if_ruby "3.0.0"..."3.2.0" do
+    if_ruby "3.0.0"..."3.2.0", skip: false do
       IO.pipe.tap do |r, w|
         w.write("hello")
 
