@@ -95,6 +95,11 @@ class KernelSingletonTest < Test::Unit::TestCase
     end
   end
 
+  def test_proc
+    assert_send_type "() { () -> untyped } -> Proc", Kernel, :proc do end
+    assert_send_type "() { () -> untyped } -> Proc", Kernel, :proc do |a, b| end
+  end
+
   def test_rand
     assert_send_type "() -> Float", Kernel, :rand
     assert_send_type "(0) -> Float", Kernel, :rand, 0
@@ -518,4 +523,42 @@ class KernelInstanceTest < Test::Unit::TestCase
     assert_send_type  '(KernelInstanceTest::JustKernel) -> KernelInstanceTest::JustKernel',
                       JustKernel.allocate, :initialize_dup, OBJ
   end
+
+  def test_system
+    with_bool do |exception|
+      assert_send_type '(String, exception: bool) -> bool',
+                       Kernel, :system, ":", exception: exception
+    end
+  end
+
+  class TestException < Exception
+  end
+
+  def test_raise
+    begin
+      assert_send_type(
+        "(_Exception, String, Array[String]) -> bot",
+        JustKernel.new, :raise, TestException, "test message", ["location.rb:123"]
+      )
+    rescue TestException
+    end
+
+    begin
+      assert_send_type(
+        "(_Exception, String, String) -> bot",
+        JustKernel.new, :raise, TestException, "test message", "location.rb:123"
+      )
+    rescue TestException
+    end
+
+    if_ruby("3.4"..., skip: false) do
+      begin
+        assert_send_type(
+          "(_Exception, String, Array[Thread::Backtrace::Location]) -> bot",
+          JustKernel.new, :raise, TestException, "test message", [caller_locations[0]]
+        )
+      rescue TestException
+      end
+    end
+  end
 end
