@@ -14,7 +14,7 @@ module OpenSSL::TestUtils
 end
 
 class OpenSSLSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL)"
 
@@ -51,7 +51,7 @@ end
 
 
 class OpenSSLASN1SingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::ASN1)"
 
@@ -179,14 +179,16 @@ class OpenSSLASN1SingletonTest < Test::Unit::TestCase
   end
 
   def test_traverse
-    der = "\x05\x00\x05\x00".b
-    assert_send_type "(String) { (::Integer, ::Integer, ::Integer, ::Integer, bool, Symbol, ::Integer) -> void } -> void",
-    OpenSSL::ASN1, :traverse, der  do |a, b, c, d, e, f, g| return a, b, c, d, e, f, g end
+    der = "\x05\x00".b
+    assert_send_type(
+      "(String) { ([::Integer, ::Integer, ::Integer, ::Integer, bool, Symbol, ::Integer]) -> void } -> void",
+      OpenSSL::ASN1, :traverse, der, &proc { }
+    )
   end
 end
 
 class OpenSSLASN1ASN1DataTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::ASN1::ASN1Data"
 
@@ -222,7 +224,7 @@ class OpenSSLASN1ASN1DataTest < Test::Unit::TestCase
 end
 
 class OpenSSLBNSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::BN)"
 
@@ -235,7 +237,7 @@ class OpenSSLBNSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLBNTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::BN"
 
@@ -260,7 +262,7 @@ class OpenSSLBNTest < Test::Unit::TestCase
 end
 
 class OpenSSLCipherSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::Cipher)"
 
@@ -273,7 +275,7 @@ end
 
 
 class OpenSSLCipherTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Cipher"
 
@@ -368,7 +370,7 @@ class OpenSSLCipherTest < Test::Unit::TestCase
 end
 
 class OpenSSLConfigSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::Config)"
 
@@ -393,7 +395,7 @@ class OpenSSLConfigSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLConfigTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Config"
 
@@ -410,8 +412,10 @@ class OpenSSLConfigTest < Test::Unit::TestCase
   end
 
   def test_each
-    assert_send_type "() { (String, String, String) -> void } -> OpenSSL::Config",
-      config, :each do |*k| return k; end
+    assert_send_type(
+      "() { ([String, String, String]) -> void } -> OpenSSL::Config",
+      config, :each, &proc { }
+    )
   end
 
   private
@@ -422,7 +426,7 @@ class OpenSSLConfigTest < Test::Unit::TestCase
 end
 
 class OpenSSLDigestSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::Digest)"
 
@@ -433,7 +437,7 @@ class OpenSSLDigestSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLDigestTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Digest"
 
@@ -470,7 +474,7 @@ class OpenSSLDigestTest < Test::Unit::TestCase
 end
 
 class OpenSSLEngineSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::Engine)"
 
@@ -486,7 +490,7 @@ class OpenSSLEngineSingletonTest < Test::Unit::TestCase
 end if defined?(OpenSSL::Engine)
 
 class OpenSSLEngineTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Engine"
 
@@ -508,7 +512,7 @@ class OpenSSLEngineTest < Test::Unit::TestCase
 end if defined?(OpenSSL::Engine)
 
 class OpenSSLHMACSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::HMAC)"
 
@@ -521,10 +525,15 @@ class OpenSSLHMACSingletonTest < Test::Unit::TestCase
     assert_send_type "(String, String, String) -> String",
       OpenSSL::HMAC, :hexdigest, "SHA256", "key", "data"
   end
+
+  def test_base64digest
+    assert_send_type "(String, String, String) -> String",
+      OpenSSL::HMAC, :base64digest, "SHA256", "key", "data"
+  end
 end
 
 class OpenSSLHMACTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::HMAC"
 
@@ -538,6 +547,11 @@ class OpenSSLHMACTest < Test::Unit::TestCase
       hmac, :hexdigest
   end
 
+  def test_base64digest
+    assert_send_type "() -> String",
+      hmac, :base64digest
+  end
+
   def test_reset
     assert_send_type "() -> OpenSSL::HMAC",
       hmac, :reset
@@ -557,7 +571,7 @@ class OpenSSLHMACTest < Test::Unit::TestCase
 end
 
 class OpenSSLKDFSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::KDF)"
 
@@ -597,7 +611,7 @@ class OpenSSLKDFSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLNetscapePKITest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Netscape::SPKI"
 
@@ -626,7 +640,7 @@ class OpenSSLNetscapePKITest < Test::Unit::TestCase
 end
 
 class OpenSSLOCSPBasicResponsePKITest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::OCSP::BasicResponse"
 
@@ -643,7 +657,7 @@ class OpenSSLOCSPBasicResponsePKITest < Test::Unit::TestCase
 end
 
 class OpenSSLPKeySingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::PKey)"
 
@@ -670,7 +684,7 @@ end
 
 
 class OpenSSLDHTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::PKey::DH"
 
@@ -720,7 +734,7 @@ class OpenSSLDHTest < Test::Unit::TestCase
 end
 
 class OpenSSLDSATest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::PKey::DSA"
 
@@ -791,7 +805,7 @@ class OpenSSLDSATest < Test::Unit::TestCase
 end
 
 class OpenSSLECSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::PKey::EC)"
 
@@ -807,7 +821,7 @@ class OpenSSLECSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLECTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::PKey::EC"
 
@@ -863,7 +877,7 @@ class OpenSSLECTest < Test::Unit::TestCase
 end
 
 class OpenSSLRSATest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::PKey::RSA"
 
@@ -910,7 +924,7 @@ class OpenSSLRSATest < Test::Unit::TestCase
 end
 
 class OpenSSLRandomSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::Random)"
 
@@ -922,7 +936,7 @@ end
 
 
 class OpenSSLSSLSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::SSL)"
 
@@ -938,7 +952,7 @@ class OpenSSLSSLSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLTimestampFactoryTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::Timestamp::Factory"
 
@@ -974,7 +988,7 @@ class OpenSSLTimestampFactoryTest < Test::Unit::TestCase
 end if OpenSSL.const_defined?(:Timestamp)
 
 class OpenSSLX509AttributeTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::X509::Attribute"
 
@@ -1003,7 +1017,7 @@ end
 
 
 class OpenSSLX509CertificateTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::X509::Certificate"
 
@@ -1034,7 +1048,7 @@ end
 
 
 class OpenSSLX509ExtensionTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::X509::Extension"
 
@@ -1069,7 +1083,7 @@ class OpenSSLX509ExtensionTest < Test::Unit::TestCase
 end
 
 class OpenSSLX509NameSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "singleton(::OpenSSL::X509::Name)"
 
@@ -1081,7 +1095,7 @@ class OpenSSLX509NameSingletonTest < Test::Unit::TestCase
 end
 
 class OpenSSLX509NameTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
   library "openssl"
   testing "::OpenSSL::X509::Name"
 
