@@ -1,8 +1,10 @@
 require_relative "../test_helper"
 require 'tempfile'
 
+return unless defined?(Tempfile::Remover)
+
 class TempfileRemoverSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   library "tempfile"
   testing "singleton(::Tempfile::Remover)"
@@ -14,7 +16,7 @@ class TempfileRemoverSingletonTest < Test::Unit::TestCase
 end
 
 class TempfileRemoverTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   library "tempfile"
   testing "::Tempfile::Remover"
