@@ -48,5 +48,16 @@ module TestSkip
         end
       end
     end
+
+    def teardown
+      case
+      when passed?
+        # nop
+      else
+        puts "💡You can skip this test `#{name}` by adding the name to `#{SKIP_TESTS_FILE}`"
+      end
+
+      super
+    end
   end
 end
